cattrs package
==============

.. automodule:: cattrs
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cattrs.gen
   cattrs.preconf
   cattrs.strategies

Submodules
----------

cattrs.cols module
------------------

.. automodule:: cattrs.cols
   :members:
   :undoc-members:
   :show-inheritance:

cattrs.disambiguators module
----------------------------

.. automodule:: cattrs.disambiguators
   :members:
   :undoc-members:
   :show-inheritance:

cattrs.dispatch module
----------------------

.. automodule:: cattrs.dispatch
   :members:
   :undoc-members:
   :show-inheritance:

cattrs.errors module
--------------------

.. automodule:: cattrs.errors
   :members:
   :undoc-members:
   :show-inheritance:

cattrs.fns module
-----------------

.. automodule:: cattrs.fns
   :members:
   :undoc-members:
   :show-inheritance:

cattrs.v module
---------------

.. automodule:: cattrs.v
   :members:
   :undoc-members:
   :show-inheritance:
